#!/bin/bash

#-----------------------------------------------------------------------
# This script show sys info in 3 forms: html, formatted text and plain text 
# by José Alberto Suárez López <bass@gentoo.org> GPLv2
# Contrib by: Pablo Nebrera, Ferdy & Jota
# 06/07/05 14:43:44 CEST
#-----------------------------------------------------------------------

#-----------------------------------------------------------------------
# DEVETH = interaface to analyse
# HTML = leave it blank if you prefer plain format
# RC_NOCOLOR = "yes" will make plain output without color
# GRAPH = make graphs with rrd
#-----------------------------------------------------------------------

CONF="/etc/recursos2.conf"
source ${CONF}

# Options
##
##Need a lot of changes to implement this
# while getopts "d:thm:w" miopt ; do
#     case $miopt in
#         t) optt="1" ;;
#         d) DEVETH="$OPTARG" ;;
#         h) opth="1" ;;
#         w) optw="1" ;;
#         m) optm="$OPTARG" ;;
#         *) echo " " "* Try -h for help"
#             exit 1;;
#     esac
# done

##
# Help
##
#ayuda () {
#    echo "${HILITE}Recursos.sh${NORMAL} ${BRACKET}[${NORMAL} ${GOOD}${VERSION}${NORMAL} ${BRACKET}]${NORMAL}"
#    echo -e " " "by José Alberto Suárez López <bass@gentoo.org> "
#    echo
#    einfo "Example :"
#    einfo "${BOLD}'basename $0' -f title net disk > system.html${NORMAL}"
#    einfo "${BOLD}'basename $0' -f -t title net disk${NORMAL}"
#    echo
#    einfo "Modules aviables: ..."
#    echo
#    exit
#}
#if [ -n "$opth" ] ; then
#    ayuda
#fi

yns () {
    einfo "You must define HTML=\"1\" or HTML=\"\" to select the output method"
}

##
# Fisrt tests
##
# if [ -f /etc/lrp.conf ] ; then
#     SYS_TYPE=Lince
# else
#     SYS_TYPE=Other
# fi

##
# MEM Functions : fmemt(total), fmemf(free), fmemu(used), fmemp(%used)
##
fmemt () {
    set -- $(${CAT} /proc/meminfo | ${GREP} MemTotal | ${AWK} '{print $2}')
    echo $(($1/1024))
}
fmemf () {
    set -- $(${CAT} /proc/meminfo | ${GREP} MemFree | ${AWK} '{print $2}')
    MEMF=$(($1/1024))
    
    set -- $(${CAT} /proc/meminfo | ${GREP} Cached | ${AWK} '{print $2}')
    MEMC=$(($1/1024))
    
    echo $(($MEMC+$MEMF))
}
fmemu () {
    MEMT=$(fmemt)
    MEMF=$(fmemf)
    echo $(($MEMT-$MEMF))
}
fmemp () {
    MEMU=$(fmemu)
    MEMT=$(fmemt)
    echo $(($MEMU*100/$MEMT))
}

##
# SWAP Functions : fswapt(total), fswapf(free), fswapu(used), fswapp(%used)
##
fswapt () {
    set -- $(${CAT} /proc/meminfo | ${GREP} SwapTotal | ${AWK} '{print $2}')
    echo $(($1/1024))
}
fswapf () {
    set -- $(${CAT} /proc/meminfo | ${GREP} SwapFree | ${AWK} '{print $2}')
    SWAPF=$(($1/1024))
    
    set -- $(${CAT} /proc/meminfo | ${GREP} SwapCached | ${AWK} '{print $2}')
    SWAPC=$(($1/1024))
    
    echo $(($SWAPT+$SWAPF))
}
fswapu () {
    SWAPF=$(fswapf)
    SWAPT=$(fswapt)
    echo $(($SWAPT-$SWAPF))
}
fswapp () {
    SWAPF=$(fswapf)
    SWAPT=$(fswapt)
    SWAPU=$(($SWAPT-$SWAPF))
    echo $(($SWAPU*100/$SWAPT))
}

##
# CPU, Procs & Users Functions : fcpu(used), fproct(total), fprocs(run,sleep,s${TOP},zomby), fusers(tty,notty)
##
fcpu () {
    if [ $SYS_TYPE = Lince ]; then
	TERM=Linux ${TOP} -n2 -b | ${GREP} "CPU" | tail -n3 | head -n1 | ${AWK} '{print $3+$5+$7}'
    else
	TERM=linux ${TOP} -n2 -b | ${GREP} "Cpu" | tail -n1 | ${AWK} '{print $2+$4+$6}'
	#IDLE=$( vmstat | grep -v ^procs | grep -v "^\ r" | awk '{print $15}' )
	#USED=$((100-${IDLE}))
	#echo ${USED}
    fi
}
fproct () {
     ps ax | wc -l | ${AWK} '{print $1}'
}
fprocs () { 
    if [ $SYS_TYPE = Lince ]; then
	TERM=Linux ${TOP} -n1 -b | ${GREP} "processes" | ${AWK} '{print $3,$5,$7,$9}'
    else
	TERM=Linux ${TOP} -n1 -b | ${GREP} "Tasks" | ${AWK} '{print $4,$6,$8,$10}'
    fi
}
fusers () {
	OFS=$IFS
IFS="
"
	ii=0; for n in `w`; do ii=$(($ii+1)); done ; echo -n $(($ii-2))
	ll=0; for n in `ps | ${GREP} notty`; do ll=$(($ll+1)); done ; echo " "$ll
	IFS=$OFS
}

##
# Iptables Functions : fipt(total rules & bridge rules)
##
fipt () {
    ${IPSAV} > /tmp/tmp.ipt.save
    ${CAT} /tmp/tmp.ipt.save | ${GREP} "^-A" | wc -l
    ${CAT} /tmp/tmp.ipt.save | ${GREP} "^-A\ br0_fwd" | wc -l
}

##
# Bandwith Functions : fbw(received, trasnmitted) This funcion is usefull to do raphs with rrdtool for example.
##
fbw () {
    if [ -f /tmp/bw-$DEVETH.tmp ]; then
	if [ -z $DEVETH ] ; then
	    DEVETH="eth0"
	fi
	set -- $(${CAT} /tmp/bw-$DEVETH.tmp)
	OLDSEC=$1
	OLDRX=$(($2*8/1024))
	OLDTX=$(($3*8/1024))
	set -- $(${IFCFG} $DEVETH | ${AWK} '/RX bytes/{print $2,$6}' | ${SED} 's/bytes://g')
	NEWRX=$(($1*8/1024))
	NEWTX=$(($2*8/1024))
	NEWSEC=$(date +%s)

	RX=$((($NEWRX-$OLDRX)/($NEWSEC-$OLDSEC)))
	TX=$((($NEWTX-$OLDTX)/($NEWSEC-$OLDSEC)))
	
	echo $RX $TX
	
	echo $NEWSEC  > /tmp/bw-$DEVETH.tmp
	echo $1 >> /tmp/bw-$DEVETH.tmp
	echo $2 >> /tmp/bw-$DEVETH.tmp
	 
    else
	## Create file with first timstamp
	set -- $(${IFCFG} $DEVETH | ${AWK} '/RX bytes/{print $2,$6}' | ${SED} 's/bytes://g')
	date +%s > /tmp/bw-$DEVETH.tmp
	echo $1 >> /tmp/bw-$DEVETH.tmp
	echo $2 >> /tmp/bw-$DEVETH.tmp

	echo "0 0"
    fi	
}

fbwn () {
    count () {
	COUNT=`cat /proc/net/dev | grep $1 | sed -e ";s/:/ /g;" | sed -e ":;s/  / /g;t" | cut -d " " -f $2`
    }
    cd /tmp
    FILENAME=bw-`date +%Y%m%d`
    count ${DEVETH} 3
    E0a=${COUNT}
    sleep 8
    count ${DEVETH} 3
    E0b=${COUNT}
    #echo -e `date | sed "s/  / /" | cut -d " " -f 4` "\t${DEVETH}:  " $((E0b-E0a))
    RX=$((E0b-E0a))

    count ${DEVETH} 11
    E0a=${COUNT}
    sleep 8
    count ${DEVETH} 11
    E0b=${COUNT}
    TX=$((E0b-E0a))

    echo $RX $TX

}

##
# System Functions : fdate(sys date), 
##
fdate () {
     date "+%A, %d %B %Y"
}
fuptime () {
    if [ $SYS_TYPE = Lince ]; then
	upSeconds=$(${CAT} /proc/uptime | tr "." " " | ${AWK} '{print $1}')
	secs=$((${upSeconds}%60))
	mins=$((${upSeconds}/60%60))
	hours=$((${upSeconds}/3600/24))
	days=$((${upSeconds}/86400))
    else
	let upSeconds="$(${CAT} /proc/uptime | tr "." " " | ${AWK} '{print $1}')"
	let secs=$((${upSeconds}%60))
	let mins=$((${upSeconds}/60%60))
	let hours=$((${upSeconds}/3600/24))
	let days=$((${upSeconds}/86400))
    fi
    if [ "${days}" -ne "0" ]
    then
	    echo -n "${days}d "
    fi
    echo "${hours}h ${mins}m"	
}

funame () {
    uname -s -r -n -m
}

##
# functions with format
##
##
# ip a Functions
##
fipa1 () {
    OFS=$IFS
IFS="
"
    for n in `${IP} a | ${SED} -e 's/</\&lt;/' -e 's/>/\&gt;/'` ; do
	echo -n $n; echo "<br>";
    done
    IFS=$OFS
}
fipa () {
    fipa1 | awk 'BEGIN {} { if (match($1, "^[0-9]+:")!=0) print "<br><B>",$0,"</B>"; else print $0;  }'
}

##
# TCP/UDP Active connections
## 

fnetstatt () {
    if [ -z "$HTML" ] ; then 
	netstat --inet -apnt | ${GREP} -v ^"Active Internet connections"
    elif [ -n "$HTML" ] ; then
	netstat --inet -apnt|${GREP} -v ^"Active Internet connections"| ${AWK} 'BEGIN { print "<TABLE align=\"center\" BORDER=0  width=\"95%\" cellspacing=\"3\" cellpadding=\"3\">"}{ if (NR==1) { print "<TR align=\"center\">","<TH bgcolor=\"#b0b0b0\">",$1,"</TH>","<TH bgcolor=\"#b0b0b0\">",$2,"</TH>","<TH bgcolor=\"#b0b0b0\">",$3,"</TH>","<TH bgcolor=\"#b0b0b0\">","Local Address","</TH>","<TH bgcolor=\"#b0b0b0\">","Foreign Address","</TH>","<TH bgcolor=\"#b0b0b0\">","State","</TH>","<TH bgcolor=\"#b0b0b0\">","PID/Program name","</TH>","</TR>";} else { if (NR%2==0) { print "<TR>","<TD bgcolor=\"#e6e6e6\">",$1,"</TD>","<TD bgcolor=\"#e6e6e6\">",$2,"</TD>","<TD bgcolor=\"#e6e6e6\">",$3,"</TD>","<TD bgcolor=\"#e6e6e6\">",$4,"</TD>","<TD bgcolor=\"#e6e6e6\">",$5,"</TD>","<TD bgcolor=\"#e6e6e6\">",$6,"</TD>","<TD bgcolor=\"#e6e6e6\">",$7,"</TD>","</TR>";} else { print "<TR>","<TD>",$1,"</TD>","<TD>",$2,"</TD>","<TD>",$3,"</TD>","<TD>",$4,"</TD>","<TD>",$5,"</TD>","<TD>",$6,"</TD>","<TD>",$7,"</TD>","</TR>";} } }END  { print "</TABLE>";}';
    else
	yns
    fi
}
fnetstatu () {
    if [ -z "$HTML" ] ; then 
	netstat --inet -apnu | ${GREP} -v ^"Active Internet connections"
    elif [ -n "$HTML" ] ; then
	netstat --inet -apnu|${GREP} -v ^"Active Internet connections"| ${AWK} 'BEGIN { print "<TABLE align=\"center\" BORDER=0  width=\"95%\" cellspacing=\"3\" cellpadding=\"3\">"}{ if (NR==1) { print "<TR align=\"center\">","<TH bgcolor=\"#b0b0b0\">",$1,"</TH>","<TH bgcolor=\"#b0b0b0\">",$2,"</TH>","<TH bgcolor=\"#b0b0b0\">",$3,"</TH>","<TH bgcolor=\"#b0b0b0\">","Local Address","</TH>","<TH bgcolor=\"#b0b0b0\">","Foreign Address","</TH>","<TH bgcolor=\"#b0b0b0\">","State  PID/Program name","</TH>","</TR>";} else { if (NR%2==0) { print "<TR>","<TD bgcolor=\"#e6e6e6\">",$1,"</TD>","<TD bgcolor=\"#e6e6e6\">",$2,"</TD>","<TD bgcolor=\"#e6e6e6\">",$3,"</TD>","<TD bgcolor=\"#e6e6e6\">",$4,"</TD>","<TD bgcolor=\"#e6e6e6\">",$5,"</TD>","<TD bgcolor=\"#e6e6e6\">",$6,"  ",$7,"</TD>","</TR>";} else { print "<TR>","<TD>",$1,"</TD>","<TD>",$2,"</TD>","<TD>",$3,"</TD>","<TD>",$4,"</TD>","<TD>",$5,"</TD>","<TD>",$6,"  ",$7,"</TD>","</TR>";} } }END  { print "</TABLE>";}';
    else
	yns
    fi
}

fpsaux () {
    if [ -z "$HTML" ] ; then
	ps aux 
    elif [ -n "$HTML" ] ; then
	ps aux | ${AWK} 'BEGIN { print "<TABLE align=\"center\" BORDER=0  width=\"95%\" cellspacing=\"3\" cellpadding=\"3\">"}{ if (NR==1) { print "<TR align=\"center\">","<TH bgcolor=\"#b0b0b0\">",$1,"</TH>","<TH bgcolor=\"#b0b0b0\">",$2,"</TH>","<TH bgcolor=\"#b0b0b0\">",$3,"</TH>","<TH bgcolor=\"#b0b0b0\">",$4,"</TH>","<TH bgcolor=\"#b0b0b0\">",$5,"</TH>","<TH bgcolor=\"#b0b0b0\">",$6,"</TH>","<TH bgcolor=\"#b0b0b0\">",$7,"</TH>","<TH bgcolor=\"#b0b0b0\">",$8,"</TH>","<TH bgcolor=\"#b0b0b0\">",$9,"</TH>","<TH bgcolor=\"#b0b0b0\">",$10,"</TH>","<TH bgcolor=\"#b0b0b0\">",$11,"</TH>","</TR>";} else { if (NR%2==0) { print "<TR>","<TD bgcolor=\"#e6e6e6\">",$1,"</TD>","<TD bgcolor=\"#e6e6e6\">",$2,"</TD>","<TD bgcolor=\"#e6e6e6\">",$3,"</TD>","<TD bgcolor=\"#e6e6e6\">",$4,"</TD>","<TD bgcolor=\"#e6e6e6\">",$5,"</TD>","<TD bgcolor=\"#e6e6e6\">",$6,"</TD>","<TD bgcolor=\"#e6e6e6\">",$7,"</TD>","<TD bgcolor=\"#e6e6e6\">",$8,"</TD>","<TD bgcolor=\"#e6e6e6\">",$9,"</TD>","<TD bgcolor=\"#e6e6e6\">",$10,"</TD>","<TD bgcolor=\"#e6e6e6\">",$11,"</TD>","</TR>";} else { print "<TR>","<TD>",$1,"</TD>","<TD>",$2,"</TD>","<TD>",$3,"</TD>","<TD>",$4,"</TD>","<TD>",$5,"</TD>","<TD>",$6,"</TD>","<TD>",$7,"</TD>","</TR>";} } }END  { print "</TABLE>";}';
    else
	yns
    fi
}

fdfh () {
    if [ $SYS_TYPE = Lince ]; then
	if [ -z "$HTML" ] ; then
	    df -h
	elif [-n "$HTML" ] ; then
	    df -h | ${GREP} -v "/dev/root"| ${GREP} -v "/dev/loop0" |${GREP} -v "/mnt1" | ${AWK} 'BEGIN { print "<TABLE align=\"center\" BORDER=0  width=\"95%\" cellspacing=\"3\" cellpadding=\"3\">"}{ if (NR==1) { print "<TR align=\"center\">","<TH bgcolor=\"#b0b0b0\">",$1,"</TH>","<TH bgcolor=\"#b0b0b0\">",$2,"</TH>","<TH bgcolor=\"#b0b0b0\">",$3,"</TH>","<TH bgcolor=\"#b0b0b0\">",$4,"</TH>","<TH bgcolor=\"#b0b0b0\">",$5,"</TH>","<TH bgcolor=\"#b0b0b0\">",$6,"</TH>","</TR>";} else { if (NR%2==0) { print "<TR>","<TD bgcolor=\"#e6e6e6\">",$1,"</TD>","<TD bgcolor=\"#e6e6e6\">",$2,"</TD>","<TD bgcolor=\"#e6e6e6\">",$3,"</TD>","<TD bgcolor=\"#e6e6e6\">",$4,"</TD>","<TD bgcolor=\"#e6e6e6\">",$5,"</TD>","<TD bgcolor=\"#e6e6e6\">",$6,"</TD>","</TR>";} else { print "<TR>","<TD>",$1,"</TD>","<TD>",$2,"</TD>","<TD>",$3,"</TD>","<TD>",$4,"</TD>","<TD>",$5,"</TD>","<TD>",$6,"</TD>","</TR>";} } }END  { print "</TABLE>"    }';
	else
	    yns
	fi
    else
	if [ -z "$HTML" ] ; then
	    df -h
	elif [ -n "$HTML" ] ; then
	    df -h | ${AWK} 'BEGIN { print "<TABLE align=\"center\" BORDER=0  width=\"95%\" cellspacing=\"3\" cellpadding=\"3\">"}{ if (NR==1) { print "<TR align=\"center\">","<TH bgcolor=\"#b0b0b0\">",$1,"</TH>","<TH bgcolor=\"#b0b0b0\">",$2,"</TH>","<TH bgcolor=\"#b0b0b0\">",$3,"</TH>","<TH bgcolor=\"#b0b0b0\">",$4,"</TH>","<TH bgcolor=\"#b0b0b0\">",$5,"</TH>","<TH bgcolor=\"#b0b0b0\">",$6,"</TH>","</TR>";} else { if (NR%2==0) { print "<TR>","<TD bgcolor=\"#e6e6e6\">",$1,"</TD>","<TD bgcolor=\"#e6e6e6\">",$2,"</TD>","<TD bgcolor=\"#e6e6e6\">",$3,"</TD>","<TD bgcolor=\"#e6e6e6\">",$4,"</TD>","<TD bgcolor=\"#e6e6e6\">",$5,"</TD>","<TD bgcolor=\"#e6e6e6\">",$6,"</TD>","</TR>";} else { print "<TR>","<TD>",$1,"</TD>","<TD>",$2,"</TD>","<TD>",$3,"</TD>","<TD>",$4,"</TD>","<TD>",$5,"</TD>","<TD>",$6,"</TD>","</TR>";} } }END  { print "</TABLE>"    }';
	else
	    yns
	fi
    fi
}

fwho () {
    if [ -z "$HTML" ] ; then
	w | ${SED} '1d'
    elif [ -n "$HTML" ] ; then
	w | ${SED} '1d' | ${AWK} 'BEGIN { print "<TABLE align=\"center\" BORDER=0  width=\"95%\" cellspacing=\"3\" cellpadding=\"3\">"}{ if (NR==1) { print "<TR align=\"center\">","<TH bgcolor=\"#b0b0b0\">",$1,"</TH>","<TH bgcolor=\"#b0b0b0\">",$2,"</TH>","<TH bgcolor=\"#b0b0b0\">",$3,"</TH>","<TH bgcolor=\"#b0b0b0\">",$4,"</TH>","<TH bgcolor=\"#b0b0b0\">",$5,"</TH>","<TH bgcolor=\"#b0b0b0\">",$6,"</TH>","<TH bgcolor=\"#b0b0b0\">",$7,"</TH>","</TR>";} else { if (NR%2==0) { print "<TR>","<TD bgcolor=\"#e6e6e6\">",$1,"</TD>","<TD bgcolor=\"#e6e6e6\">",$2,"</TD>","<TD bgcolor=\"#e6e6e6\">",$3,"</TD>","<TD bgcolor=\"#e6e6e6\">",$4,"</TD>","<TD bgcolor=\"#e6e6e6\">",$5,"</TD>","<TD bgcolor=\"#e6e6e6\">",$6,"</TD>","<TD bgcolor=\"#e6e6e6\">",$7,"</TD>","</TR>";} else { print "<TR>","<TD>",$1,"</TD>","<TD>",$2,"</TD>","<TD>",$3,"</TD>","<TD>",$4,"</TD>","<TD>",$5,"</TD>","<TD>",$6,"</TD>","<TD>",$7,"</TD>","</TR>";} } }END  { print "</TABLE>";}';
    else
	yns
    fi
}

froute () {
    if [ -z "$HTML" ] ; then
	netstat -r | ${SED} '1d'
    elif [ -n "$HTML" ] ; then
	netstat -r | ${SED} '1d' | ${AWK} 'BEGIN { print "<TABLE align=\"center\" BORDER=0  width=\"95%\" cellspacing=\"3\" cellpadding=\"3\">"}{ if (NR==1) { print "<TR align=\"center\">","<TH bgcolor=\"#b0b0b0\">",$1,"</TH>","<TH bgcolor=\"#b0b0b0\">",$2,"</TH>","<TH bgcolor=\"#b0b0b0\">",$3,"</TH>","<TH bgcolor=\"#b0b0b0\">",$4,"</TH>","<TH bgcolor=\"#b0b0b0\">",$5,"</TH>","<TH bgcolor=\"#b0b0b0\">",$6,"</TH>","<TH bgcolor=\"#b0b0b0\">",$7,"</TH>","<TH bgcolor=\"#b0b0b0\">",$8,"</TH>","</TR>";} else { if (NR%2==0) { print "<TR>","<TD bgcolor=\"#e6e6e6\">",$1,"</TD>","<TD bgcolor=\"#e6e6e6\">",$2,"</TD>","<TD bgcolor=\"#e6e6e6\">",$3,"</TD>","<TD bgcolor=\"#e6e6e6\">",$4,"</TD>","<TD bgcolor=\"#e6e6e6\">",$5,"</TD>","<TD bgcolor=\"#e6e6e6\">",$6,"</TD>","<TD bgcolor=\"#e6e6e6\">",$7,"</TD>","<TD bgcolor=\"#e6e6e6\">",$8,"</TD>","</TR>";} else { print "<TR>","<TD>",$1,"</TD>","<TD>",$2,"</TD>","<TD>",$3,"</TD>","<TD>",$4,"</TD>","<TD>",$5,"</TD>","<TD>",$6,"</TD>","<TD>",$7,"</TD>","<TD>",$8,"</TD>","</TR>";} } }END  { print "</TABLE>";}';
    else
	yns
    fi
}

fprocst () {
    set -- $(fprocs)
    if [ $SYS_TYPE = Lince ]; then
	if [ -z "$HTML" ] ; then
	    einfo "Process sleeping : $1"
	    einfo "Process Running  : $2"
	    einfo "Process Zombie   : $3"
	    einfo "Process stopped  : $4"
	elif [ -n "$HTML" ] ; then
${CAT} <<- _EOF_
	<table>
	<tr>
	    <td><b>Sleeping:</b></td>
	    <td>$(echo $1)</td>
	</tr>
	<tr>
	    <td bgcolor="#e6e6e6"><b>Running:</b></td>
	    <td bgcolor="#e6e6e6">$(echo $2)</td>
	</tr>
	<tr>
	    <td><b>Zombie:</b></td>
	    <td>$(echo $3)</td>
	</tr>
	<tr>
	    <td bgcolor="#e6e6e6"><b>Stopped:</b></td>
	    <td bgcolor="#e6e6e6">$(echo $4)</td>
	</tr>
	</table>
_EOF_
	else
	    yns
	fi
    else
	if [ -z "$HTML" ] ; then
	    einfo "Process sleeping : $2"
	    einfo "Process Running  : $1"
	    einfo "Process Zombie   : $4"
	    einfo "Process stopped  : $3"
	elif [ -n "$HTML" ] ; then
${CAT} <<- _EOF_
	<table>
	<tr>
	    <td><b>Running:</b></td>
	    <td>$(echo $1)</td>
	</tr>
	<tr>
	    <td bgcolor="#e6e6e6"><b>Sleeping:</b></td>
	    <td bgcolor="#e6e6e6">$(echo $2)</td>
	</tr>
	<tr>
	    <td><b>Stopped:</b></td>
	    <td>$(echo $3)</td>
	</tr>
	<tr>
	    <td bgcolor="#e6e6e6"><b>Zombie:</b></td>
	    <td bgcolor="#e6e6e6">$(echo $4)</td>
	</tr>
	</table>
_EOF_
	else
	    yns
	fi
    fi
}

title () {
${CAT} <<- _EOF_
    <head>
    <title>System Report</title>
    </head>
    <font face="arial,helvetica">
    <center><h2><b><font face="arial,helvetica"  face="arial,helvetica"  size="6px" color="#FFA500">:</font></b> System Report - $(date "+%c") </b><b><font face="arial,helvetica"  size="6px" color="#FFA500">:</font></b></h2></center>
    <center><h4><font face="arial,helvetica"  color="5f5f5f"><b>Eneo Tecnolog&iacute;a S.L.</b> <a href="http://www.eneotecnologia.com">www.eneotecnologia.com</a></font></h4></center>
    <hr align="center" width="50%">
_EOF_
}

summary () {
    # this will show all the info w/o format ot indi${CAT}ions, just numbers ever in the same order. Perfect to be used by other program to do nice things ;)
    fverb "This mean :"
    fverb "CPU used%, Total process, Mem free, Mem used%, Mem total, Swap free, Swap used%, Swap total, Used bandwith received & transmited in $DEV"
    echo
    fcpu ; fproct ; fmemf ; fmemp ; fmemt ; fswapf ; fswapp ; fswapt ; fbw ; echo
}

general () {
    if [ -z "$HTML" ] ; then
	echo
	echo -e "${BRACKET}:::::${NORMAL} ${HILITE}General${NORMAL}"
	echo
	einfo "System Date	    : $(fdate)"
	einfo "Uptime	    :$(uptime)"
	einfo "Active Users	    : $(fusers | ${AWK} '{print $1}')"
	einfo "NoTTY Users	    : $(fusers | ${AWK} '{print $2}')"
	einfo "Connected TTY Users  : "
	fwho
	echo
    elif [ -n "$HTML" ] ; then
${CAT} <<- _EOF_
    <p>
    <h3><b><font face="arial,helvetica"  size="5px" color="#FFA500">:</font></b><b> General Info</b></h3>
    <table align="center" width="95%" cellspacing="3" cellpadding="3" border="0">
    <tr>
	<td><b>System Date :</b></td>
	<td>$(fdate)</td>
    </tr>
    <tr>
	<td bgcolor="#e6e6e6"><b>Uptime :</b></td>
	<td bgcolor="#e6e6e6">$(fuptime)</td>
    </tr>
    <tr>
	<td><b>Active Users :</b></td>
	<td>$(fusers | ${AWK} '{print $1'})</td>
    </tr>
    <tr>
	<td bgcolor="#e6e6e6"><b>NoTTY Users :</b></td>
	<td bgcolor="#e6e6e6">$(fusers | ${AWK} '{print $2}')</td>
    </tr>
    </tr>
    <tr>
	<td><b>Connected TTY Users :</b></td>
	<td>$(fwho)</td>
    </table>
_EOF_
    else
	yns
    fi
}

system () {
    if [ -z "$HTML" ] ; then
	echo
        echo -e "${BRACKET}:::::${NORMAL} ${HILITE}System${NORMAL}"
        echo
        einfo "CPU Used		: $(fcpu)%"
        einfo "Tasks Number		: $(fproct)"
        einfo "  " "Sleeping		: $(fprocs | ${AWK} '{print $1'})"
        einfo "  " "Running		: $(fprocs | ${AWK} '{print $2'})"
        einfo "  " "zombie		: $(fprocs | ${AWK} '{print $3'})"
        einfo "  " "Stopped		: $(fprocs | ${AWK} '{print $4'})"
        echo
    elif [ -n "$HTML" ]  ; then
${CAT} <<- _EOF_
    <p>
    <h3><b><font face="arial,helvetica"  size="5px" color="#FFA500">:</font></b><b> Tasks and Cpu Info</b></h3>
    <table align="center" width="95%" cellspacing="3" cellpadding="3" border="0">
    <tr>
	<td><b>Cpu Usage :</b></td>
	<td>$(fcpu)%</td>
    </tr>
    <tr>
	<td bgcolor="#e6e6e6"><b>Tasks Numbers :</b></td>
	<td bgcolor="#e6e6e6">$(fproct)</td>
    </tr>
    <tr>
	<td><b>Tasks State :</b></td>
	<td>$(fprocst)</td>
    </tr>
    </table>
_EOF_
    else
	yns
    fi
}

disks () {
    if [ -z "$HTML" ] ; then
	echo
	echo -e "${BRACKET}:::::${NORMAL} ${HILITE}File System & Mem${NORMAL}"
	echo
	einfo "Used Ram	""  "": $(fmemp)% of $(fmemt)Mb"
	einfo "Used Swap""  "": $(fswapp)% of $(fswapt)Mb"
	echo
	einfo "Disk Usage	:"
	fdfh
    elif [ -n "$HTML" ] ; then
${CAT} <<- _EOF_
    <p>
    <h3><b><font face="arial,helvetica"  size="5px" color="#FFA500">:</font></b><b> Mem Info</b></h3>
    <table align="center" width="95%" cellspacing="3" cellpadding="1" border="0">
    <tr>
	<td><b>Used Ram :</b></td>
	<td>$(fmemp)% of $(fmemt)Mb</td>
    </tr>
    <tr>
	<td bgcolor="#e6e6e6"><b>Used Swap :</b></td>
	<td bgcolor="#e6e6e6">$(fswapp)% of $(fswapt)Mb</td>
    </tr>
    </table>
    <p>
    <h3><b><font face="arial,helvetica"  size="5px" color="#FFA500">:</font></b><b> Disk Usage</b></h3>
    $(fdfh)
_EOF_
    else
	yns
    fi
}

net () {
    set -- $(fipt)
    if [ -z "$HTML" ] ; then
	echo
	echo -e "${BRACKET}:::::${NORMAL} ${HILITE}Network${NORMAL}"
	echo
	einfo "IPTables :"
	einfo "	    " "Total Number of Rules			: $(echo $1)"
	einfo "	    " "Total Number of Rules in zone bw0_fwd	: $(echo $2)"
	echo
	einfo "Uncomment line 585-589 to have netstat output"
#         einfo "TCP Network Info :"
#         fnetstatt
#         echo
#         einfo "UDP Network Info :"
#         fnetstatu
	echo
	einfo "Route Table :"
	froute
	echo
	einfo "Network Interfaces :"
	fipa
    elif [ -n "$HTML" ] ; then
${CAT} <<- _EOF_
    <p>
    <h3><b><font face="arial,helvetica"  size="5px" color="#FFA500">:</font></b><b> IPTables Rules</b></h3>
    <table align="center" width="95%" cellspacing="3" cellpadding="1" border="0">
    <tr>
	<td><b>Total Number of Rules :</b></td>
	<td>$(echo $1)</td>
    </tr>
    <tr>
	<td bgcolor="#e6e6e6"><b>Total Number of Rules in zone bw0_fwd :</b></td>
	<td bgcolor="#e6e6e6">$(echo $2)</td>
    </tr>
    </table>
    <p>
    <h3><b><font face="arial,helvetica"  size="5px" color="#FFA500">:</font></b><b> TCP Network Info</b></h3>
    $(fnetstatt)
    <p>
    <h3><b><font face="arial,helvetica"  size="5px" color="#FFA500">:</font></b><b> UDP Network Info</b></h3>
    $(fnetstatu)
    <h3><b><font face="arial,helvetica"  size="5px" color="#FFA500">:</font></b><b> Route Table</b></font></h3>
    $(froute)
    <p>
    <h3><b><font face="arial,helvetica"  size="5px" color="#FFA500">:</font></b><b> Network Interfaces</b></font></h3>
    <table align="center">
    $(fipa)
_EOF_
    else
	yns
    fi
}

$1
$2
$3
$4
$5
$6
$7
$8
$9


